Module Name:    src
Committed By:   msaitoh
Date:           Thu Jul 11 03:49:52 UTC 2019

Modified Files:
        src/sys/arch/i386/stand/bootxx: bootxx.S
        src/sys/arch/m68k/m68k: db_disasm.c
        src/sys/dev/pci: if_vgereg.h
        src/sys/dev/raidframe: rf_dagflags.h rf_stripelocks.c
        src/sys/net: if_slvar.h if_spppsubr.c if_stripvar.h zlib.c
        src/tests/bin/sh: t_option.sh
        src/usr.bin/sort: sort.1
        src/usr.sbin/altq/libaltq: altq_qop.h
        src/usr.sbin/kgmon: kgmon.c
        src/usr.sbin/route6d: route6d.c

Log Message:
Fix typo (s/supress/suppress/).


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.11 src/sys/arch/i386/stand/bootxx/bootxx.S
cvs rdiff -u -r1.42 -r1.43 src/sys/arch/m68k/m68k/db_disasm.c
cvs rdiff -u -r1.3 -r1.4 src/sys/dev/pci/if_vgereg.h
cvs rdiff -u -r1.5 -r1.6 src/sys/dev/raidframe/rf_dagflags.h
cvs rdiff -u -r1.33 -r1.34 src/sys/dev/raidframe/rf_stripelocks.c
cvs rdiff -u -r1.33 -r1.34 src/sys/net/if_slvar.h
cvs rdiff -u -r1.182 -r1.183 src/sys/net/if_spppsubr.c
cvs rdiff -u -r1.19 -r1.20 src/sys/net/if_stripvar.h
cvs rdiff -u -r1.36 -r1.37 src/sys/net/zlib.c
cvs rdiff -u -r1.6 -r1.7 src/tests/bin/sh/t_option.sh
cvs rdiff -u -r1.38 -r1.39 src/usr.bin/sort/sort.1
cvs rdiff -u -r1.6 -r1.7 src/usr.sbin/altq/libaltq/altq_qop.h
cvs rdiff -u -r1.25 -r1.26 src/usr.sbin/kgmon/kgmon.c
cvs rdiff -u -r1.73 -r1.74 src/usr.sbin/route6d/route6d.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/i386/stand/bootxx/bootxx.S
diff -u src/sys/arch/i386/stand/bootxx/bootxx.S:1.10 src/sys/arch/i386/stand/bootxx/bootxx.S:1.11
--- src/sys/arch/i386/stand/bootxx/bootxx.S:1.10	Thu Jan  6 01:08:48 2011
+++ src/sys/arch/i386/stand/bootxx/bootxx.S	Thu Jul 11 03:49:51 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: bootxx.S,v 1.10 2011/01/06 01:08:48 jakllsch Exp $	*/
+/*	$NetBSD: bootxx.S,v 1.11 2019/07/11 03:49:51 msaitoh Exp $	*/
 
 /*-
  * Copyright (c) 2003 The NetBSD Foundation, Inc.
@@ -98,7 +98,7 @@ boot_fail:
 	aam				/* largest errno is < 100 */
 	addw	$('0' << 8) | '0', %ax	/* to ascii */
 	rorw	$8, %ax
-	cmpb	$'0', %al		/* supress leading zero */
+	cmpb	$'0', %al		/* suppress leading zero */
 	jne	10f
 	movb	$' ', %al
 10:	movw	%ax, 12f

Index: src/sys/arch/m68k/m68k/db_disasm.c
diff -u src/sys/arch/m68k/m68k/db_disasm.c:1.42 src/sys/arch/m68k/m68k/db_disasm.c:1.43
--- src/sys/arch/m68k/m68k/db_disasm.c:1.42	Tue Feb  5 07:18:52 2019
+++ src/sys/arch/m68k/m68k/db_disasm.c	Thu Jul 11 03:49:51 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: db_disasm.c,v 1.42 2019/02/05 07:18:52 mrg Exp $	*/
+/*	$NetBSD: db_disasm.c,v 1.43 2019/07/11 03:49:51 msaitoh Exp $	*/
 
 /*
  * Copyright (c) 1994 Christian E. Hopps
@@ -63,7 +63,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: db_disasm.c,v 1.42 2019/02/05 07:18:52 mrg Exp $");
+__KERNEL_RCSID(0, "$NetBSD: db_disasm.c,v 1.43 2019/07/11 03:49:51 msaitoh Exp $");
 
 #include <sys/param.h>
 #ifdef _KERNEL
@@ -2691,7 +2691,7 @@ get_modregstr_mit(dis_buffer_t *dbuf, in
 			    bd == 3 ? SIZE_LONG :
 			    SIZE_BYTE);
 			if (od && !ISBITSET(ext,6) && !ISBITSET(ext,2))
-				/* Pre-indexed and not supressing index */
+				/* Pre-indexed and not suppressing index */
 				addchar(',');
 			else if (od && ISBITSET(ext,2)) {
 				/* Post-indexed */

Index: src/sys/dev/pci/if_vgereg.h
diff -u src/sys/dev/pci/if_vgereg.h:1.3 src/sys/dev/pci/if_vgereg.h:1.4
--- src/sys/dev/pci/if_vgereg.h:1.3	Tue Oct 31 14:13:30 2006
+++ src/sys/dev/pci/if_vgereg.h	Thu Jul 11 03:49:51 2019
@@ -240,8 +240,8 @@
 #define VGE_INTCTL_HC_RELOAD		0x02 /* enable hold timer reload */
 #define VGE_INTCTL_STATUS		0x04 /* interrupt pending status */
 #define VGE_INTCTL_MASK			0x18 /* multilayer int mask */
-#define VGE_INTCTL_RXINTSUP_DISABLE	0x20 /* disable RX int supression */
-#define VGE_INTCTL_TXINTSUP_DISABLE	0x40 /* disable TX int supression */
+#define VGE_INTCTL_RXINTSUP_DISABLE	0x20 /* disable RX int suppression */
+#define VGE_INTCTL_TXINTSUP_DISABLE	0x40 /* disable TX int suppression */
 #define VGE_INTCTL_SOFTINT		0x80 /* request soft interrupt */
 
 #define VGE_INTMASK_LAYER0		0x00
@@ -384,8 +384,8 @@
  *   the multicast hash filter or the CAM table)
  * - The behavior of the interrupt holdoff timer register at offset
  *   0x20 (the page select bits allow you to set the interrupt
- *   holdoff timer, the TX interrupt supression count or the
- *   RX interrupt supression count)
+ *   holdoff timer, the TX interrupt suppression count or the
+ *   RX interrupt suppression count)
  * - The behavior the WOL pattern programming registers at offset
  *   0xC0 (controls which pattern is set)
  */

Index: src/sys/dev/raidframe/rf_dagflags.h
diff -u src/sys/dev/raidframe/rf_dagflags.h:1.5 src/sys/dev/raidframe/rf_dagflags.h:1.6
--- src/sys/dev/raidframe/rf_dagflags.h:1.5	Sun Dec 11 12:23:37 2005
+++ src/sys/dev/raidframe/rf_dagflags.h	Thu Jul 11 03:49:51 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: rf_dagflags.h,v 1.5 2005/12/11 12:23:37 christos Exp $	*/
+/*	$NetBSD: rf_dagflags.h,v 1.6 2019/07/11 03:49:51 msaitoh Exp $	*/
 /*
  * Copyright (c) 1995 Carnegie-Mellon University.
  * All rights reserved.
@@ -43,12 +43,12 @@
  * by DoAccess, SelectAlgorithm, and the DAG creation routines.
  *
  * If USE_DAG or USE_ASM is specified, neither the DAG nor the ASM
- * will be modified, which means that you can't SUPRESS if you
+ * will be modified, which means that you can't SUPPRESS if you
  * specify USE_DAG.
  */
 
 #define RF_DAG_FLAGS_NONE             0	/* no flags */
-#define RF_DAG_SUPPRESS_LOCKS     (1<<0)	/* supress all stripe locks in
+#define RF_DAG_SUPPRESS_LOCKS     (1<<0)	/* suppress all stripe locks in
 						 * the DAG */
 #define RF_DAG_NONBLOCKING_IO     (1<<3)	/* cause DoAccess to be
 						 * non-blocking */

Index: src/sys/dev/raidframe/rf_stripelocks.c
diff -u src/sys/dev/raidframe/rf_stripelocks.c:1.33 src/sys/dev/raidframe/rf_stripelocks.c:1.34
--- src/sys/dev/raidframe/rf_stripelocks.c:1.33	Sat Feb  9 03:34:00 2019
+++ src/sys/dev/raidframe/rf_stripelocks.c	Thu Jul 11 03:49:51 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: rf_stripelocks.c,v 1.33 2019/02/09 03:34:00 christos Exp $	*/
+/*	$NetBSD: rf_stripelocks.c,v 1.34 2019/07/11 03:49:51 msaitoh Exp $	*/
 /*
  * Copyright (c) 1995 Carnegie-Mellon University.
  * All rights reserved.
@@ -57,7 +57,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: rf_stripelocks.c,v 1.33 2019/02/09 03:34:00 christos Exp $");
+__KERNEL_RCSID(0, "$NetBSD: rf_stripelocks.c,v 1.34 2019/07/11 03:49:51 msaitoh Exp $");
 
 #include <dev/raidframe/raidframevar.h>
 
@@ -262,7 +262,7 @@ rf_AcquireStripeLock(RF_LockTableEntry_t
 #if RF_DEBUG_STRIPELOCK
 	if (rf_stripeLockDebug) {
 		if (stripeID == -1) {
-			Dprintf1("[%d] Lock acquisition supressed (stripeID == -1)\n", tid);
+			Dprintf1("[%d] Lock acquisition suppressed (stripeID == -1)\n", tid);
 		} else {
 			Dprintf8("[%d] Trying to acquire stripe lock table 0x%lx SID %ld type %c range %ld-%ld, range2 %ld-%ld hashval %d\n",
 			    tid, (unsigned long) lockTable, stripeID, lockReqDesc->type, lockReqDesc->start,
@@ -385,7 +385,7 @@ rf_ReleaseStripeLock(RF_LockTableEntry_t
 #if RF_DEBUG_STRIPELOCK
 	if (rf_stripeLockDebug) {
 		if (stripeID == -1) {
-			Dprintf1("[%d] Lock release supressed (stripeID == -1)\n", tid);
+			Dprintf1("[%d] Lock release suppressed (stripeID == -1)\n", tid);
 		} else {
 			Dprintf8("[%d] Releasing stripe lock on stripe ID %ld, type %c range %ld-%ld %ld-%ld table 0x%lx\n",
 			    tid, stripeID, lockReqDesc->type, lockReqDesc->start, lockReqDesc->stop, lockReqDesc->start2, lockReqDesc->stop2, lockTable);

Index: src/sys/net/if_slvar.h
diff -u src/sys/net/if_slvar.h:1.33 src/sys/net/if_slvar.h:1.34
--- src/sys/net/if_slvar.h:1.33	Sat Jul 14 21:02:41 2007
+++ src/sys/net/if_slvar.h	Thu Jul 11 03:49:51 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_slvar.h,v 1.33 2007/07/14 21:02:41 ad Exp $	*/
+/*	$NetBSD: if_slvar.h,v 1.34 2019/07/11 03:49:51 msaitoh Exp $	*/
 
 /*-
  * Copyright (c) 1991, 1993
@@ -74,7 +74,7 @@ struct sl_softc {
 
 /* visible flags */
 #define	SC_COMPRESS	IFF_LINK0	/* compress TCP traffic */
-#define	SC_NOICMP	IFF_LINK1	/* supress ICMP traffic */
+#define	SC_NOICMP	IFF_LINK1	/* suppress ICMP traffic */
 #define	SC_AUTOCOMP	IFF_LINK2	/* auto-enable TCP compression */
 
 #endif /* _NET_IF_SLVAR_H_ */

Index: src/sys/net/if_spppsubr.c
diff -u src/sys/net/if_spppsubr.c:1.182 src/sys/net/if_spppsubr.c:1.183
--- src/sys/net/if_spppsubr.c:1.182	Fri Mar  1 11:06:57 2019
+++ src/sys/net/if_spppsubr.c	Thu Jul 11 03:49:51 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_spppsubr.c,v 1.182 2019/03/01 11:06:57 pgoyette Exp $	 */
+/*	$NetBSD: if_spppsubr.c,v 1.183 2019/07/11 03:49:51 msaitoh Exp $	 */
 
 /*
  * Synchronous PPP/Cisco link level subroutines.
@@ -41,7 +41,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_spppsubr.c,v 1.182 2019/03/01 11:06:57 pgoyette Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_spppsubr.c,v 1.183 2019/07/11 03:49:51 msaitoh Exp $");
 
 #if defined(_KERNEL_OPT)
 #include "opt_inet.h"
@@ -4571,7 +4571,7 @@ sppp_chap_tlu(struct sppp *sp)
 		if ((sp->hisauth.flags & SPPP_AUTHFLAG_NORECHALLENGE) == 0)
 			addlog("next re-challenge in %d seconds\n", i);
 		else
-			addlog("re-challenging supressed\n");
+			addlog("re-challenging suppressed\n");
 	}
 
 	x = splnet();

Index: src/sys/net/if_stripvar.h
diff -u src/sys/net/if_stripvar.h:1.19 src/sys/net/if_stripvar.h:1.20
--- src/sys/net/if_stripvar.h:1.19	Sat Jul 14 21:02:42 2007
+++ src/sys/net/if_stripvar.h	Thu Jul 11 03:49:51 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_stripvar.h,v 1.19 2007/07/14 21:02:42 ad Exp $	*/
+/*	$NetBSD: if_stripvar.h,v 1.20 2019/07/11 03:49:51 msaitoh Exp $	*/
 
 #ifndef _NET_IF_STRIPVAR_H_
 #define _NET_IF_STRIPVAR_H_
@@ -50,7 +50,7 @@ struct strip_softc {
 
 /* visible flags */
 #define	SC_COMPRESS	IFF_LINK0	/* compress TCP traffic */
-#define	SC_NOICMP	IFF_LINK1	/* supress ICMP traffic */
+#define	SC_NOICMP	IFF_LINK1	/* suppress ICMP traffic */
 #define	SC_AUTOCOMP	IFF_LINK2	/* auto-enable TCP compression */
 
 #ifdef _KERNEL

Index: src/sys/net/zlib.c
diff -u src/sys/net/zlib.c:1.36 src/sys/net/zlib.c:1.37
--- src/sys/net/zlib.c:1.36	Tue Feb 19 00:26:57 2019
+++ src/sys/net/zlib.c	Thu Jul 11 03:49:51 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: zlib.c,v 1.36 2019/02/19 00:26:57 christos Exp $	*/
+/*	$NetBSD: zlib.c,v 1.37 2019/07/11 03:49:51 msaitoh Exp $	*/
 /*
  * This file is derived from various .h and .c files from the zlib-1.0.4
  * distribution by Jean-loup Gailly and Mark Adler, with some additions
@@ -11,7 +11,7 @@
  * - added inflateIncomp and deflateOutputPending
  * - allow strm->next_out to be NULL, meaning discard the output
  *
- * $Id: zlib.c,v 1.36 2019/02/19 00:26:57 christos Exp $
+ * $Id: zlib.c,v 1.37 2019/07/11 03:49:51 msaitoh Exp $
  */
 
 /*
@@ -22,7 +22,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: zlib.c,v 1.36 2019/02/19 00:26:57 christos Exp $");
+__KERNEL_RCSID(0, "$NetBSD: zlib.c,v 1.37 2019/07/11 03:49:51 msaitoh Exp $");
 
 #define NO_DUMMY_DECL
 #define NO_ZCFUNCS
@@ -45,7 +45,7 @@ __KERNEL_RCSID(0, "$NetBSD: zlib.c,v 1.3
    subject to change. Applications should only use zlib.h.
  */
 
-/* @(#) $Id: zlib.c,v 1.36 2019/02/19 00:26:57 christos Exp $ */
+/* @(#) $Id: zlib.c,v 1.37 2019/07/11 03:49:51 msaitoh Exp $ */
 
 #ifndef _Z_UTIL_H
 #define _Z_UTIL_H
@@ -294,7 +294,7 @@ void   zcfree(voidpf opaque, voidpf ptr)
    subject to change. Applications should only use zlib.h.
  */
 
-/* @(#) $Id: zlib.c,v 1.36 2019/02/19 00:26:57 christos Exp $ */
+/* @(#) $Id: zlib.c,v 1.37 2019/07/11 03:49:51 msaitoh Exp $ */
 
 #ifndef _DEFLATE_H
 #define _DEFLATE_H
@@ -461,7 +461,7 @@ typedef struct deflate_state {
     int nice_match; /* Stop searching when current match exceeds this */
 
                 /* used by trees.c: */
-    /* Didn't use ct_data typedef below to supress compiler warning */
+    /* Didn't use ct_data typedef below to suppress compiler warning */
     struct ct_data_s dyn_ltree[HEAP_SIZE];   /* literal and length tree */
     struct ct_data_s dyn_dtree[2*D_CODES+1]; /* distance tree */
     struct ct_data_s bl_tree[2*BL_CODES+1];  /* Huffman tree for bit lengths */
@@ -656,7 +656,7 @@ void _tr_stored_type_only(deflate_state 
  *
  */
 
-/* @(#) $Id: zlib.c,v 1.36 2019/02/19 00:26:57 christos Exp $ */
+/* @(#) $Id: zlib.c,v 1.37 2019/07/11 03:49:51 msaitoh Exp $ */
 
 /* #include "deflate.h" */
 
@@ -1999,7 +1999,7 @@ local block_state deflate_slow(deflate_s
  *          Addison-Wesley, 1983. ISBN 0-201-06672-6.
  */
 
-/* @(#) $Id: zlib.c,v 1.36 2019/02/19 00:26:57 christos Exp $ */
+/* @(#) $Id: zlib.c,v 1.37 2019/07/11 03:49:51 msaitoh Exp $ */
 
 /* #define GEN_TREES_H */
 
@@ -5813,7 +5813,7 @@ void  zcfree (opaque, ptr)
  * For conditions of distribution and use, see copyright notice in zlib.h
  */
 
-/* @(#) $Id: zlib.c,v 1.36 2019/02/19 00:26:57 christos Exp $ */
+/* @(#) $Id: zlib.c,v 1.37 2019/07/11 03:49:51 msaitoh Exp $ */
 
 /* #include "zlib.h" */
 

Index: src/tests/bin/sh/t_option.sh
diff -u src/tests/bin/sh/t_option.sh:1.6 src/tests/bin/sh/t_option.sh:1.7
--- src/tests/bin/sh/t_option.sh:1.6	Thu Nov 16 19:41:41 2017
+++ src/tests/bin/sh/t_option.sh	Thu Jul 11 03:49:51 2019
@@ -1,4 +1,4 @@
-# $NetBSD: t_option.sh,v 1.6 2017/11/16 19:41:41 kre Exp $
+# $NetBSD: t_option.sh,v 1.7 2019/07/11 03:49:51 msaitoh Exp $
 #
 # Copyright (c) 2016 The NetBSD Foundation, Inc.
 # All rights reserved.
@@ -258,7 +258,7 @@ set_f_body() {
 
 atf_test_case set_n
 set_n_head() {
-	atf_set "descr" "Tests that 'set -n' supresses command execution " \
+	atf_set "descr" "Tests that 'set -n' suppresses command execution " \
 	                "and that it behaves as defined by the standard"
 }
 set_n_body() {

Index: src/usr.bin/sort/sort.1
diff -u src/usr.bin/sort/sort.1:1.38 src/usr.bin/sort/sort.1:1.39
--- src/usr.bin/sort/sort.1:1.38	Mon Jul  3 21:34:21 2017
+++ src/usr.bin/sort/sort.1	Thu Jul 11 03:49:51 2019
@@ -1,4 +1,4 @@
-.\"	$NetBSD: sort.1,v 1.38 2017/07/03 21:34:21 wiz Exp $
+.\"	$NetBSD: sort.1,v 1.39 2019/07/11 03:49:51 msaitoh Exp $
 .\"
 .\" Copyright (c) 2000-2003 The NetBSD Foundation, Inc.
 .\" All rights reserved.
@@ -411,7 +411,7 @@ and
 option settings.
 With
 .Fl u
-the records are considered identical, and one is supressed.
+the records are considered identical, and one is suppressed.
 Otherwise with
 .Fl s
 set (default) the records are left in their original order,

Index: src/usr.sbin/kgmon/kgmon.c
diff -u src/usr.sbin/kgmon/kgmon.c:1.25 src/usr.sbin/kgmon/kgmon.c:1.26
--- src/usr.sbin/kgmon/kgmon.c:1.25	Sun Oct 17 16:13:56 2010
+++ src/usr.sbin/kgmon/kgmon.c	Thu Jul 11 03:49:52 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: kgmon.c,v 1.25 2010/10/17 16:13:56 uebayasi Exp $	*/
+/*	$NetBSD: kgmon.c,v 1.26 2019/07/11 03:49:52 msaitoh Exp $	*/
 
 /*
  * Copyright (c) 1983, 1992, 1993
@@ -39,7 +39,7 @@ __COPYRIGHT("@(#) Copyright (c) 1983, 19
 #if 0
 static char sccsid[] = "from: @(#)kgmon.c	8.1 (Berkeley) 6/6/93";
 #else
-__RCSID("$NetBSD: kgmon.c,v 1.25 2010/10/17 16:13:56 uebayasi Exp $");
+__RCSID("$NetBSD: kgmon.c,v 1.26 2019/07/11 03:49:52 msaitoh Exp $");
 #endif
 #endif /* not lint */
 
@@ -221,11 +221,11 @@ kern_readonly(int mode)
 	if (pflag && mode == GMON_PROF_ON)
 		(void)fprintf(stderr, "data may be inconsistent\n");
 	if (rflag)
-		(void)fprintf(stderr, "-r supressed\n");
+		(void)fprintf(stderr, "-r suppressed\n");
 	if (bflag)
-		(void)fprintf(stderr, "-b supressed\n");
+		(void)fprintf(stderr, "-b suppressed\n");
 	if (hflag)
-		(void)fprintf(stderr, "-h supressed\n");
+		(void)fprintf(stderr, "-h suppressed\n");
 	rflag = bflag = hflag = 0;
 }
 

Index: src/usr.sbin/route6d/route6d.c
diff -u src/usr.sbin/route6d/route6d.c:1.73 src/usr.sbin/route6d/route6d.c:1.74
--- src/usr.sbin/route6d/route6d.c:1.73	Tue Feb  5 06:17:03 2019
+++ src/usr.sbin/route6d/route6d.c	Thu Jul 11 03:49:52 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: route6d.c,v 1.73 2019/02/05 06:17:03 msaitoh Exp $	*/
+/*	$NetBSD: route6d.c,v 1.74 2019/07/11 03:49:52 msaitoh Exp $	*/
 /*	$KAME: route6d.c,v 1.94 2002/10/26 20:08:55 itojun Exp $	*/
 
 /*
@@ -32,7 +32,7 @@
 
 #include <sys/cdefs.h>
 #ifndef	lint
-__RCSID("$NetBSD: route6d.c,v 1.73 2019/02/05 06:17:03 msaitoh Exp $");
+__RCSID("$NetBSD: route6d.c,v 1.74 2019/07/11 03:49:52 msaitoh Exp $");
 #endif
 
 #include <stdbool.h>
@@ -149,7 +149,7 @@ static struct	rip6 *ripbuf;	/* packet bu
  * One of the major drawbacks of the linear linked list is the difficulty
  * of representing the relationship between a couple of routes.  This may
  * be a significant problem when we have to support route aggregation with
- * supressing the specifices covered by the aggregate.
+ * suppressing the specifices covered by the aggregate.
  */
 
 struct	riprt {

Reply via email to
Index: src/usr.sbin/altq/libaltq/altq_qop.h
diff -u src/usr.sbin/altq/libaltq/altq_qop.h:1.6 src/usr.sbin/altq/libaltq/altq_qop.h:1.7
--- src/usr.sbin/altq/libaltq/altq_qop.h:1.6	Tue Aug 16 12:49:13 2011
+++ src/usr.sbin/altq/libaltq/altq_qop.h	Thu Jul 11 03:49:51 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: altq_qop.h,v 1.6 2011/08/16 12:49:13 christos Exp $	*/
+/*	$NetBSD: altq_qop.h,v 1.7 2019/07/11 03:49:51 msaitoh Exp $	*/
 /*	$KAME: altq_qop.h,v 1.5 2002/02/12 10:14:01 kjc Exp $	*/
 /*
  * Copyright (C) 1999-2000
@@ -121,7 +121,7 @@ struct fltrinfo {
 
 	/* for consistency check */
 	int			line_no;	/* config file line number */
-	int			dontwarn;	/* supress warning msg */
+	int			dontwarn;	/* suppress warning msg */
 };
 
 int do_command(FILE *infp);
@@ -216,7 +216,7 @@ int client_input(FILE *fp);
 
 #define QOPERR_MAX		18
 
-extern int	filter_dontwarn;/* supress warning for the current filter */
+extern int	filter_dontwarn;/* suppress warning for the current filter */
 extern const char *altqconfigfile;	/* config file name */
 extern const char *qop_errlist[];	/* error string list */
 extern struct qdisc_ops nop_qdisc;
